@@ -5,7 +5,7 @@ from celery.exceptions import TaskRevokedError
 from dagster import check
 from dagster.core.errors import DagsterSubprocessError
 from dagster.core.events import DagsterEvent, EngineEventData
-from dagster.core.execution.context.system import SystemPipelineExecutionContext
+from dagster.core.execution.context.system import PlanOrchestrationContext
 from dagster.core.execution.plan.plan import ExecutionPlan
 from dagster.core.storage.tags import PRIORITY_TAG
 from dagster.serdes import deserialize_json_to_dagster_namedtuple
@@ -25,18 +25,20 @@ DELEGATE_MARKER = "celery_queue_wait"
 
 def core_celery_execution_loop(pipeline_context, execution_plan, step_execution_fn):
 
-    check.inst_param(pipeline_context, "pipeline_context", SystemPipelineExecutionContext)
+    check.inst_param(pipeline_context, "pipeline_context", PlanOrchestrationContext)
     check.inst_param(execution_plan, "execution_plan", ExecutionPlan)
     check.callable_param(step_execution_fn, "step_execution_fn")
 
     executor = pipeline_context.executor
 
-    # https://github.com/dagster-io/dagster/issues/2440
-    check.invariant(
-        execution_plan.artifacts_persisted,
-        "Cannot use in-memory storage with Celery, use filesystem (on top of NFS or "
-        "similar system that allows files to be available to all nodes), S3, or GCS",
-    )
+    # If there are no step keys to execute, then any io managers will not be used.
+    if len(execution_plan.step_keys_to_execute) > 0:
+        # https://github.com/dagster-io/dagster/issues/2440
+        check.invariant(
+            execution_plan.artifacts_persisted,
+            "Cannot use in-memory storage with Celery, use filesystem (on top of NFS or "
+            "similar system that allows files to be available to all nodes), S3, or GCS",
+        )
 
     app = make_app(executor.app_args())
 
@@ -53,7 +55,7 @@ def core_celery_execution_loop(pipeline_context, execution_plan, step_execution_
     step_errors = {}
 
     with execution_plan.start(
-        retries=pipeline_context.executor.retries,
+        retry_mode=pipeline_context.executor.retries,
         sort_key_fn=priority_for_step,
     ) as active_execution:
 
@@ -87,7 +89,7 @@ def core_celery_execution_loop(pipeline_context, execution_plan, step_execution_
                             EngineEventData(marker_end=DELEGATE_MARKER),
                             step_handle=active_execution.get_step_by_key(step_key).handle,
                         )
-                    except Exception:  # pylint: disable=broad-except
+                    except Exception:
                         # We will want to do more to handle the exception here.. maybe subclass Task
                         # Certainly yield an engine or pipeline event
                         step_events = []
@@ -136,7 +138,12 @@ def core_celery_execution_loop(pipeline_context, execution_plan, step_execution_
 
                     # Submit the Celery tasks
                     step_results[step.key] = step_execution_fn(
-                        app, pipeline_context, step, queue, priority
+                        app,
+                        pipeline_context,
+                        step,
+                        queue,
+                        priority,
+                        active_execution.get_known_state(),
                     )
 
                 except Exception:
